@@ -1,12 +1,12 @@
 package Catalyst::ActionRole::DetachOnDie;
 {
-  $Catalyst::ActionRole::DetachOnDie::VERSION = '0.001005';
+  $Catalyst::ActionRole::DetachOnDie::VERSION = '0.001006';
 }
 use Moose::Role;
 use Try::Tiny;
 use Scalar::Util qw(blessed);
 
-# ABSTRACT: If something dies in a chain, stop the chain
+# ABSTRACT: If something dies in a chain, stop the chain. DEPRECATED IN FAVOR OF CATALYST 5.90040
 
 around execute => sub {
    my ($orig, $self, $controller, $c, @args) = @_;
@@ -34,11 +34,11 @@ __END__
 
 =head1 NAME
 
-Catalyst::ActionRole::DetachOnDie - If something dies in a chain, stop the chain
+Catalyst::ActionRole::DetachOnDie - If something dies in a chain, stop the chain. DEPRECATED IN FAVOR OF CATALYST 5.90040
 
 =head1 VERSION
 
-version 0.001005
+version 0.001006
 
 =head1 SYNOPSIS
 
@@ -78,13 +78,18 @@ If you do not want to use the action role, check out
 L<Catalyst::Action::DetachOnDie>, which does the same thing but does not
 require the use of L<Catalyst::Controller::ActionRole>.
 
+=head1 DEPRECATED
+
+Instead of using this module you should use Catalyst 5.90040 and set
+the C<abort_chain_on_error_fix> flag.
+
 =head1 AUTHOR
 
 Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2013 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
